==> openshift-model-5.0.0-sources.jar: annotations/io/fabric8/openshift/api/model/OAuthClientAuthorizationListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class OAuthClientAuthorizationListBuilder extends OAuthClientAuthorizationListFluentImpl<OAuthClientAuthorizationListBuilder> implements VisitableBuilder<OAuthClientAuthorizationList,OAuthClientAuthorizationListBuilder> {

    OAuthClientAuthorizationListFluent<?> fluent;
    Boolean validationEnabled;

    public OAuthClientAuthorizationListBuilder() { 
        this(true);
    }


    public OAuthClientAuthorizationListBuilder(Boolean validationEnabled) { 
        this(new OAuthClientAuthorizationList(), validationEnabled);
    }


    public OAuthClientAuthorizationListBuilder(OAuthClientAuthorizationListFluent<?> fluent) { 
        this(fluent, true);
    }


    public OAuthClientAuthorizationListBuilder(OAuthClientAuthorizationListFluent<?> fluent,Boolean validationEnabled) { 
        this(fluent, new OAuthClientAuthorizationList(), validationEnabled);
    }


    public OAuthClientAuthorizationListBuilder(OAuthClientAuthorizationListFluent<?> fluent,OAuthClientAuthorizationList instance) { 
        this(fluent, instance, true);
    }


    public OAuthClientAuthorizationListBuilder(OAuthClientAuthorizationListFluent<?> fluent,OAuthClientAuthorizationList instance,Boolean validationEnabled) { 
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }


    public OAuthClientAuthorizationListBuilder(OAuthClientAuthorizationList instance) { 
        this(instance,true);
    }


    public OAuthClientAuthorizationListBuilder(OAuthClientAuthorizationList instance,Boolean validationEnabled) { 
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }


    public OAuthClientAuthorizationList build() {
        OAuthClientAuthorizationList buildable = new OAuthClientAuthorizationList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        OAuthClientAuthorizationListBuilder that = (OAuthClientAuthorizationListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> openshift-model-5.3.2-sources.jar: annotations/io/fabric8/openshift/api/model/OAuthClientAuthorizationListBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class OAuthClientAuthorizationListBuilder extends OAuthClientAuthorizationListFluentImpl<OAuthClientAuthorizationListBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<OAuthClientAuthorizationList,OAuthClientAuthorizationListBuilder> {

    OAuthClientAuthorizationListFluent<?> fluent;
    Boolean validationEnabled;

    public OAuthClientAuthorizationListBuilder() {
        this(true);
    }

    public OAuthClientAuthorizationListBuilder(Boolean validationEnabled) {
        this(new OAuthClientAuthorizationList(), validationEnabled);
    }

    public OAuthClientAuthorizationListBuilder(OAuthClientAuthorizationListFluent<?> fluent) {
        this(fluent, true);
    }

    public OAuthClientAuthorizationListBuilder(OAuthClientAuthorizationListFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new OAuthClientAuthorizationList(), validationEnabled);
    }

    public OAuthClientAuthorizationListBuilder(OAuthClientAuthorizationListFluent<?> fluent,OAuthClientAuthorizationList instance) {
        this(fluent, instance, true);
    }

    public OAuthClientAuthorizationListBuilder(OAuthClientAuthorizationListFluent<?> fluent,OAuthClientAuthorizationList instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withItems(instance.getItems()); 
        fluent.withKind(instance.getKind()); 
        fluent.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public OAuthClientAuthorizationListBuilder(OAuthClientAuthorizationList instance) {
        this(instance,true);
    }

    public OAuthClientAuthorizationListBuilder(OAuthClientAuthorizationList instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withItems(instance.getItems()); 
        this.withKind(instance.getKind()); 
        this.withMetadata(instance.getMetadata()); 
        this.validationEnabled = validationEnabled; 
    }

    public OAuthClientAuthorizationList build() {
        OAuthClientAuthorizationList buildable = new OAuthClientAuthorizationList(fluent.getApiVersion(),fluent.getItems(),fluent.getKind(),fluent.getMetadata());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        OAuthClientAuthorizationListBuilder that = (OAuthClientAuthorizationListBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
